# 📚 Geomathlib

geomathlib - это Python библиотека, предоставляющая функциональность для работы с геометрическими фигурами. Библиотека предоставляет абстрактные классы и методы для расчета площадей фигур, а также определения типа треугольника.

## Основные компоненты

### Класс `Figure`

`Figure` - это абстрактный базовый класс для геометрических фигур. Он определяет абстрактный метод `area()`, который должен быть реализован в подклассах.

### Класс `Circle`

`Circle` представляет круг и содержит методы для расчета площади круга. Он также имеет строковое представление круга.

### Класс `Triangle`

`Triangle` представляет треугольник и содержит методы для расчета площади треугольника. Он также имеет строковое представление треугольника.

### Класс `TriangleType`

`TriangleType` предоставляет метод `is_right_triangle()`, который проверяет, является ли треугольник прямоугольным.

### Класс `FigureArea`

`FigureArea` предоставляет метод `calc_area()`, который вычисляет площадь фигуры с использованием метода `area()` фигуры.

## Использование

Пример использования библиотеки:

```python
from src.area_calculator import  Circle, Triangle, FigureArea

# Создаем круг
circle = Circle(5)
print(f"Площадь круга: {circle.area()}")

# Создаем треугольник
triangle = Triangle(3, 4, 5)
print(f"Площадь треугольника: {triangle.area()}")

# Проверяем, является ли треугольник прямоугольным
if TriangleType.is_right_triangle(triangle):
    print("Треугольник является прямоугольным")
else:
    print("Треугольник не является прямоугольным")

# Вычисляем площадь фигуры через экземпляр класса
figure_area = FigureArea(circle)
print(f"Площадь фигуры: {figure_area.calc_area()}")


